// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';

class SymbolButtonThemeExtensionImpl extends SymbolButtonThemeExtension {
  const SymbolButtonThemeExtensionImpl({
    super.disabledStyle,
    super.focusedStyle,
    super.hoveredStyle,
    super.normalStyle,
    super.tappedStyle,
    super.selectedStyle,
  });

  factory SymbolButtonThemeExtensionImpl.light({ThemeData? theme}) {
    theme ??= ThemeData.light();
    final style = SymbolButtonStyle(
      labelStyle: theme.textTheme.labelLarge,
      radius: BorderRadius.circular(15),
      padding: const EdgeInsets.all(10),
      foregroundColors: const MultiColor([
        Color(0xFF3C97FB),
        Color(0xFF436EF4),
      ]),
      backgroundColors: const MultiColor.single(Color(0xFFDDE0E3)),
      borderColors: const MultiColor([
        Color(0xFF3C97FB),
        Color(0xFF436EF4),
      ]),
      stroke: 3,
    );
    return SymbolButtonThemeExtensionImpl(
      normalStyle: style,
      disabledStyle: style.copyWith(
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color(0xFF3C97FB).withOpacity(0.4),
        ),
        foregroundColors:
            MultiColor.single(const Color(0xFF3C97FB).withOpacity(0.4)),
        backgroundColors: const MultiColor.single(Color(0xFFDDE0E3)),
        borderColors:
            MultiColor.single(const Color(0xFF3C97FB).withOpacity(0.4)),
        stroke: 1,
      ),
      hoveredStyle: style.copyWith(
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color(0xFFDDE0E3),
        ),
        foregroundColors: const MultiColor.single(Color(0xFFDDE0E3)),
        backgroundColors: const MultiColor([
          Color(0xFF3C97FB),
          Color(0xFF436EF4),
        ]),
      ),
      focusedStyle: style.copyWith(stroke: 5),
      tappedStyle: style.copyWith(
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color(0xFFDDE0E3),
        ),
        foregroundColors: const MultiColor.single(Color(0xFFDDE0E3)),
        backgroundColors: const MultiColor([
          Color(0xFF4B68FF),
          Color(0xFF3531F5),
        ]),
        borderColors: const MultiColor([
          Color(0xFF4B68FF),
          Color(0xFF3531F5),
        ]),
      ),
      selectedStyle: style.copyWith(
        foregroundColors: const MultiColor.single(Color(0xFFDDE0E3)),
        borderColors: const MultiColor([
          Color(0xFF00D16C),
          Color(0xFF00D16C),
        ]),
      ),
    );
  }

  factory SymbolButtonThemeExtensionImpl.dark({ThemeData? theme}) {
    theme ??= ThemeData.dark();
    final style = SymbolButtonStyle(
      labelStyle: theme.textTheme.labelLarge,
      radius: BorderRadius.circular(15),
      padding: const EdgeInsets.all(10),
      foregroundColors: const MultiColor.single(Color(0xFFDDE0E3)),
      backgroundColors: const MultiColor.single(Color(0xFF24262A)),
      borderColors: const MultiColor([
        Color(0xFF3C97FB),
        Color(0xFF436EF4),
      ]),
      stroke: 3,
    );
    return SymbolButtonThemeExtensionImpl(
      normalStyle: style,
      disabledStyle: style.copyWith(
        labelStyle: theme.textTheme.labelLarge?.copyWith(
          color: const Color(0xFF60656A),
        ),
        foregroundColors: const MultiColor.single(Color(0xFF60656A)),
        backgroundColors: const MultiColor.single(Color(0xFF33373E)),
        borderColors: const MultiColor([Color(0xFF60656A), Color(0xFF383C40)]),
        stroke: 1,
      ),
      hoveredStyle: style.copyWith(
        foregroundColors: const MultiColor.single(Color(0xFFDDE0E3)),
        backgroundColors: const MultiColor([
          Color(0xFF3C97FB),
          Color(0xFF436EF4),
        ]),
      ),
      focusedStyle: style.copyWith(stroke: 5),
      tappedStyle: style.copyWith(
        foregroundColors: const MultiColor.single(Color(0xFFDDE0E3)),
        backgroundColors: const MultiColor([
          Color(0xFF4B68FF),
          Color(0xFF3531F5),
        ]),
        borderColors: const MultiColor([
          Color(0xFF4B68FF),
          Color(0xFF3531F5),
        ]),
      ),
      selectedStyle: style.copyWith(
        foregroundColors: const MultiColor.single(Color(0xFFDDE0E3)),
        borderColors: const MultiColor([
          Color(0xFF00D16C),
          Color(0xFF00D16C),
        ]),
      ),
    );
  }
}
